<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="175"/>
        <source>Enter your Google account data</source>
        <translation>Sartu zure Google kontuaren datuak</translation>
    </message>
    <message>
        <location filename="retext.py" line="184"/>
        <source>Username</source>
        <translation>Erabiltzailea</translation>
    </message>
    <message>
        <location filename="retext.py" line="185"/>
        <source>Password</source>
        <translation>Pasahitza</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="1330"/>
        <source>New document</source>
        <translation>Dokumentu berria</translation>
    </message>
    <message>
        <location filename="retext.py" line="245"/>
        <source>File toolbar</source>
        <translation>Fitxategi menu barra</translation>
    </message>
    <message>
        <location filename="retext.py" line="247"/>
        <source>Edit toolbar</source>
        <translation>Edizio menu barra</translation>
    </message>
    <message>
        <location filename="retext.py" line="249"/>
        <source>Search toolbar</source>
        <translation>Bilakera menu barra</translation>
    </message>
    <message>
        <location filename="retext.py" line="251"/>
        <source>New</source>
        <translation>Berria</translation>
    </message>
    <message>
        <location filename="retext.py" line="253"/>
        <source>Open</source>
        <translation>Ireki</translation>
    </message>
    <message>
        <location filename="retext.py" line="255"/>
        <source>Save</source>
        <translation>Gorde</translation>
    </message>
    <message>
        <location filename="retext.py" line="258"/>
        <source>Save as</source>
        <translation>Gorde honela...</translation>
    </message>
    <message>
        <location filename="retext.py" line="260"/>
        <source>Print</source>
        <translation>Inprimatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="262"/>
        <source>Print preview</source>
        <translation>Inprimatzeko aurrebista</translation>
    </message>
    <message>
        <location filename="retext.py" line="264"/>
        <source>View HTML code</source>
        <translation>HTML iturburua ikusi</translation>
    </message>
    <message>
        <location filename="retext.py" line="265"/>
        <source>Change default font</source>
        <translation>Lehenetsitako letra-tipoa aldatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="266"/>
        <source>Find text</source>
        <translation>Bilatu testua</translation>
    </message>
    <message>
        <location filename="retext.py" line="270"/>
        <source>Preview</source>
        <translation>Aurrebista</translation>
    </message>
    <message>
        <location filename="retext.py" line="279"/>
        <source>Live preview</source>
        <translation>Aurrebista zuzenean</translation>
    </message>
    <message>
        <location filename="retext.py" line="281"/>
        <source>Fullscreen mode</source>
        <translation>Pantaila osoa</translation>
    </message>
    <message>
        <location filename="retext.py" line="288"/>
        <source>Other formats</source>
        <translation>Beste formatuak</translation>
    </message>
    <message>
        <location filename="retext.py" line="294"/>
        <source>Quit</source>
        <translation>Kendu</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Undo</source>
        <translation>Desegin</translation>
    </message>
    <message>
        <location filename="retext.py" line="299"/>
        <source>Redo</source>
        <translation>Berregin</translation>
    </message>
    <message>
        <location filename="retext.py" line="301"/>
        <source>Copy</source>
        <translation>Kopiatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="303"/>
        <source>Cut</source>
        <translation>Ebaki</translation>
    </message>
    <message>
        <location filename="retext.py" line="305"/>
        <source>Paste</source>
        <translation>Itsatsi</translation>
    </message>
    <message>
        <location filename="retext.py" line="315"/>
        <source>Enable</source>
        <translation>Gaitu</translation>
    </message>
    <message>
        <location filename="retext.py" line="316"/>
        <source>Set locale</source>
        <translation>Lokala aukeratu</translation>
    </message>
    <message>
        <location filename="retext.py" line="325"/>
        <source>Plain text</source>
        <translation>Testu arrunta</translation>
    </message>
    <message>
        <location filename="retext.py" line="413"/>
        <source>Open recent</source>
        <translation>Azken dokumentuak</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Generate webpages</source>
        <translation>Web orriak sortu</translation>
    </message>
    <message>
        <location filename="retext.py" line="335"/>
        <source>Show</source>
        <translation>Erakutsi</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Next</source>
        <translation>Hurrengoa</translation>
    </message>
    <message>
        <location filename="retext.py" line="337"/>
        <source>Previous</source>
        <translation>Aurrekoa</translation>
    </message>
    <message>
        <location filename="retext.py" line="339"/>
        <source>Get help online</source>
        <translation>Laguntza on-line</translation>
    </message>
    <message>
        <location filename="retext.py" line="347"/>
        <source>About Qt</source>
        <translation>Qt-i buruz</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>Save to Google Docs</source>
        <translation>Gorde Google Docs-en</translation>
    </message>
    <message>
        <location filename="retext.py" line="380"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="retext.py" line="384"/>
        <source>Symbols</source>
        <translation>Sinboloak</translation>
    </message>
    <message>
        <location filename="retext.py" line="408"/>
        <source>File</source>
        <translation>Fitxategia</translation>
    </message>
    <message>
        <location filename="retext.py" line="409"/>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Help</source>
        <translation>Laguntza</translation>
    </message>
    <message>
        <location filename="retext.py" line="416"/>
        <source>Directory</source>
        <translation>Karpeta</translation>
    </message>
    <message>
        <location filename="retext.py" line="424"/>
        <source>Export</source>
        <translation>Esportatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="450"/>
        <source>Spell check</source>
        <translation>Egiaztatu ortografia</translation>
    </message>
    <message>
        <location filename="retext.py" line="458"/>
        <source>Default editing mode</source>
        <translation>Lehenetsitako editatzeko modua</translation>
    </message>
    <message>
        <location filename="retext.py" line="499"/>
        <source>Search</source>
        <translation>Bilatu</translation>
    </message>
    <message>
        <location filename="retext.py" line="503"/>
        <source>Case sensitively</source>
        <translation>Maiuskulak/minuskulak</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Ez duzu ez Markdown, ez Docutils instalatuta!</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Only HTML formatting will be available.</source>
        <translation>Bakarrik HTML formatua eskuragarri.</translation>
    </message>
    <message>
        <location filename="retext.py" line="726"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Sartu hizkuntzako prefijoa (adibidez: eu_EU)</translation>
    </message>
    <message>
        <location filename="retext.py" line="813"/>
        <source>Please, save the file somewhere.</source>
        <translation>Gorde fitxategia edonon, mesedez.</translation>
    </message>
    <message>
        <location filename="retext.py" line="800"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Web orriak &lt;code&gt;html&lt;/code&gt; karpetan gorde dira.</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Select one or several files to open</source>
        <translation>Aukeratu fitzategi bat(zuk) irekitzeko</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Supported files</source>
        <translation>Onartutako formatuak</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>All files (*)</source>
        <translation>Fitxategi guztiak (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="984"/>
        <source>Plain text (*.txt)</source>
        <translation>Testu arrunta (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="987"/>
        <source>ReStructuredText files</source>
        <translation>ReStructuredText fitxategiak</translation>
    </message>
    <message>
        <location filename="retext.py" line="990"/>
        <source>HTML files</source>
        <translation>HTML fitxategiak</translation>
    </message>
    <message>
        <location filename="retext.py" line="993"/>
        <source>Markdown files</source>
        <translation>Markdown fitxategiak</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>Save file</source>
        <translation>Gorde fitxategia</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>Export document to ODT</source>
        <translation>Esportatu ODT gisa</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Ireki OpenDocument testu fitxategiak (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML fitxategiak (*.html, *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>Export document to PDF</source>
        <translation>Esportatu PDF gisa</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF fitxategiak (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1109"/>
        <source>Print document</source>
        <translation>Inprimatu dokumentua</translation>
    </message>
    <message>
        <location filename="retext.py" line="1158"/>
        <source>This function is not available in Plain text mode!</source>
        <translation>Ekintza hau ezin da testu arrunta moduan egin!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1161"/>
        <source>Select type</source>
        <translation>Aukeratu mota</translation>
    </message>
    <message>
        <location filename="retext.py" line="1128"/>
        <source>Export document</source>
        <translation>Esportatu dokumentua</translation>
    </message>
    <message>
        <location filename="retext.py" line="1224"/>
        <source>Incorrect user name or password!</source>
        <translation>Erabiltzailearen pasa hitza okerra!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1299"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokumentua aldatu da.
Aldaketak gorde nahi duzu?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1337"/>
        <source>HTML code</source>
        <translation>HTML iturburua</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Markdown et ReStructuredText-erako editore sinple baina boteretsua</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Egilea :Dmity Schachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Website</source>
        <translation>Webgune</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Markdown syntax</source>
        <translation>Markdown sintaxia</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>ReST syntax</source>
        <translation>Rest sintaxia</translation>
    </message>
    <message>
        <location filename="retext.py" line="1411"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Ezin da fitxategiaren edukia prozesatu, beharrezko moduluak instalatuta dauden egiaztatu!</translation>
    </message>
    <message>
        <location filename="retext.py" line="802"/>
        <source>Show directory</source>
        <translation>Karpeta erakutsi</translation>
    </message>
    <message>
        <location filename="retext.py" line="807"/>
        <source>Webpages generator is not installed!</source>
        <translation>Weborri sortzailea ez dago instalatua&gt;</translation>
    </message>
    <message>
        <location filename="retext.py" line="1008"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Ezin da gorde fitxategia irakurtzeko-soilik delako!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1227"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Autentifikazioak huts egin du, konprobatu zure interneteko konexioa!</translation>
    </message>
    <message>
        <location filename="retext.py" line="368"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="369"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="461"/>
        <source>Formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="344"/>
        <source>About %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="327"/>
        <source>Use WebKit renderer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="retext.py" line="1151"/>
        <source>Failed to execute the command:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
